import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { CommonModule } from '@angular/common';
import { FormBuilder, FormGroup, FormsModule, ReactiveFormsModule, Validators } from '@angular/forms';
import { catchError, Observable } from 'rxjs';
import { AuthService } from '../data-access/Services/ApiService.service';
import { response } from 'express';
@Component({
  selector: 'meu-login',
  standalone: true,
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss'],
  imports: [CommonModule, FormsModule, ReactiveFormsModule],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class LoginComponent implements OnInit {
  loginForm: FormGroup;
  constructor(private fb: FormBuilder, private authService: AuthService) {
    this.loginForm = this.fb.group({
      username: ['', [Validators.required]],
      password: ['', [Validators.required]],
    });
  }
  ngOnInit() {}
  onSubmit() {
    const headers  = new HttpHeaders()
    if (!this.loginForm.valid) {
      alert('vui lòng nhập đầy đủ thông tin');
      return;
    }
    console.log(this.loginForm.value.username, this.loginForm.value.password);

    this.authService.login(this.loginForm.value.username, this.loginForm.value.password).pipe(
      catchError((error) => {
        console.log(error);
        throw error;
      })
    ).subscribe(
      response => {
        alert(response.message);
      }
    );
  }
}
